"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DCIRuleHelpers_1 = require("../DCIRuleHelpers");
exports.default = (0, DCIRuleHelpers_1.createRule)({
    name: "private-role-access",
    create(context) {
        return (0, DCIRuleHelpers_1.contextRules)(context, {
            ":matches(MemberExpression, CallExpression) > Identifier"(identifier) {
                const dciContext = (0, DCIRuleHelpers_1.isInContext)();
                if (!dciContext)
                    return;
                const currentRM = (0, DCIRuleHelpers_1.isInRoleMethod)();
                if (dciContext.roles.has(identifier.name)) {
                    // Check for ROLE.member access
                    if (!currentRM || currentRM.role != identifier.name) {
                        context.report({
                            node: identifier,
                            messageId: "externalContractCall",
                        });
                    }
                }
                else {
                    // Check for ROLE_method access
                    const rm = dciContext.roleMethodFromName(identifier.name);
                    if (rm && rm.isPrivate && rm.role != currentRM?.role) {
                        context.report({
                            node: identifier,
                            messageId: "privateCall",
                        });
                    }
                }
            },
        });
    },
    meta: {
        docs: {
            description: "The Role can only be accessed through its own RoleMethods.",
            recommended: "error",
        },
        messages: {
            privateCall: "Accessing a private RoleMethod outside its Role.",
            externalContractCall: "Accessing the Role contract outside its own RoleMethods.",
        },
        type: "problem",
        schema: [],
    },
    defaultOptions: [],
});
//# sourceMappingURL=private-role-access.js.map